package futils.filters;

import java.io.*;
import java.util.Date;
import java.util.prefs.Preferences;

/**
 * Copyright DocJava, inc. User: lyon
 * <p/>
 * Date: Jan 8, 2005
 * <p/>
 * Time: 8:47:05 AM
 */
public class DateFilterBean implements Serializable {
    private boolean isDirectory = true;
    private boolean isFile = true;
    private boolean dated = true;

    private Date date = new Date();
    private static final String key = "DateFilterBean";

    private DateFilterBean() {

    }

    public String toString() {
        return "isDirectory="+isDirectory+
                "\nisFile="+isFile+
                "\ndate="+date;
    }


    public FileFilter getFileFilter() {
        final boolean isDirectoryOrFile = isDirectory() || isFile();

        final boolean acceptEverything = isDirectoryOrFile &&!isDated();
        final boolean acceptOnlyFiles = isFile() && !isDirectory();
        final boolean acceptAllFiles = acceptOnlyFiles && !isDated();
        final boolean acceptOnlyDirectories = !isFile() && isDirectory();
        final boolean acceptAllDirectories = acceptOnlyDirectories &&
                !isDated();
        final boolean acceptFilesAfterDate = acceptOnlyFiles && isDated();
        final boolean acceptDirsAfterDate = acceptOnlyDirectories &&
                isDated();
        final boolean acceptAllAfterDate = isDirectoryOrFile && isDated();
        FileFilter ff = new DateFilter(this, acceptEverything,
        acceptAllFiles,
        acceptAllDirectories,
        acceptFilesAfterDate,
        acceptDirsAfterDate,
        acceptAllAfterDate);
        return ff;
    }

    public boolean isDirectory() {
        return isDirectory;
    }

    public void setDirectory(boolean directory) {
        isDirectory = directory;
    }

    public boolean isFile() {
        return isFile;
    }

    public void setFile(boolean file) {
        isFile = file;
    }

    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    /**
     * saves the properties to the Preferences of the userRoot
     */
    public void save() {
        try {
            Preferences p = Preferences.userRoot();
            ByteArrayOutputStream baos = new
                    ByteArrayOutputStream();
            ObjectOutputStream oos = new
                    ObjectOutputStream(baos);
            oos.writeObject(this);
            baos.close();
            p.putByteArray(key, baos.toByteArray());
        } catch (IOException e) {
            //e.printStackTrace();
        }
    }

    /**
     * restores the properties from the preference in the user root.
     */
    public static DateFilterBean restore() {
        try {
            Preferences p = Preferences.userRoot();
            byte b [] = p.getByteArray(key, null);
            if (b == null)
                return new DateFilterBean();
            ByteArrayInputStream bais = new
                    ByteArrayInputStream(b);
            ObjectInputStream ois = new
                    ObjectInputStream(bais);
            Object o = ois.readObject();
            bais.close();
            return (DateFilterBean) o;
        } catch (IOException e) {
        } catch (ClassNotFoundException e) {
        }
        return new DateFilterBean();
    }

    public boolean isDated() {
        return dated;
    }

    public void setDated(boolean dated) {
        this.dated = dated;
    }
}
